@@ -11,6 +11,10 @@ def create(accumulator_name):
         from fdrtd.plugins.simon.accumulators.accumulator_basic_sum import AccumulatorSecureSum
         return AccumulatorSecureSum
 
+    if accumulator_name == 'SecureMatrixMultiplication':
+        from fdrtd.plugins.simon.accumulators.accumulator_generic import AccumulatorGeneric
+        return AccumulatorGeneric
+
     if accumulator_name == 'SetIntersection':
         from fdrtd.plugins.simon.accumulators.accumulator_set_intersection import AccumulatorSetIntersection
         return AccumulatorSetIntersection
@@ -35,4 +39,12 @@ def create(accumulator_name):
         from fdrtd.plugins.simon.accumulators.accumulator_statistics_univariate import AccumulatorStatisticsUnivariate
         return AccumulatorStatisticsUnivariate
 
+    if accumulator_name == 'StatisticsContingencyVertical':
+        from fdrtd.plugins.simon.accumulators.accumulator_generic_dictionary import AccumulatorGenericDictionary
+        return AccumulatorGenericDictionary
+
+    if accumulator_name == 'StatisticsRegressionOLSVertical':
+        from fdrtd.plugins.simon.accumulators.accumulator_generic import AccumulatorGeneric
+        return AccumulatorGeneric
+
     raise fdrtd.server.exceptions.NotAvailable(accumulator_name)
